.. heka-cef documentation master file, created by
   sphinx-quickstart on Fri Mar 30 07:26:19 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst


.. toctree::
   :glob:

   config
   msg_layout
   api/*

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

